==> littlewizard_1.1.4.orig.tar.gz: littlewizard-1.1.4/liblanguage/commandmod.cc <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

 /* (C) Marcin Kwadrans <quar@vitea.pl> */

#include "include/support.h"
#include "include/command.h"
#include "include/message.h"

class LWCommandMod: public LWCommand {
	
LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
{
	(void) context;
	
	g_return_val_if_fail (argc == 2, NULL);
	
	gint divider = args[1]->toInt();
	
	if (divider == 0)
		throw new LWMessage (LW_ERROR_DivisionByZero);
	
	gint r = args[0]->toInt() % divider;
	
	return new LWValue (r);
}

gchar *getName (void)
{
	return "mod";
}	

gchar *getHint ()
{
	return _("Modulo");
}

guint getPriority (void)
{
	return 13;
}

LWLink getLinkType ()
{
	return LW_LINK_LEFT;
}

gboolean hasReturn()
{
	return TRUE;
}

void checkArgument (guint n, LWValue *value)
{
	if (n == 1)
		if (0 == value->toInt())
			throw new LWMessage (LW_ERROR_DivisionByZero);
}

void checkArgc (guint n)
{
	if (n != 2) 
		throw new LWMessage (LW_ERROR_WrongNumberOfArguments);
}

};

LWSymbol *new_LWCommandMod()
{
	return new LWCommandMod();
}

==> littlewizard_1.1.5.orig.tar.gz: littlewizard-1.1.5/liblanguage/commandmod.cc <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

 /* (C) Marcin Kwadrans <quar@vitea.pl> */

#include "include/support.h"
#include "include/command.h"
#include "include/message.h"

class LWCommandMod: public LWCommand {
	
LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
{
	(void) context;
	
	g_return_val_if_fail (argc == 2, NULL);
	
	gint divider = args[1]->toInt();
	
	if (divider == 0)
		throw new LWMessage (LW_ERROR_DivisionByZero);
	
	gint r = args[0]->toInt() % divider;
	
	return new LWValue (r);
}

const gchar *getName (void)
{
	return "mod";
}	

gchar *getHint ()
{
	return _("Modulo");
}

guint getPriority (void)
{
	return 13;
}

LWLink getLinkType ()
{
	return LW_LINK_LEFT;
}

gboolean hasReturn()
{
	return TRUE;
}

void checkArgument (guint n, LWValue *value)
{
	if (n == 1)
		if (0 == value->toInt())
			throw new LWMessage (LW_ERROR_DivisionByZero);
}

void checkArgc (guint n)
{
	if (n != 2) 
		throw new LWMessage (LW_ERROR_WrongNumberOfArguments);
}

};

LWSymbol *new_LWCommandMod()
{
	return new LWCommandMod();
}
